#
# spec file for package pgadmin4
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global	pgadmin4instdir %{_libdir}/pgadmin4-%{version}
Name:           pgadmin4
Version:        4.1
Release:        lp151.1.2
Summary:        Management tool for PostgreSQL
License:        PostgreSQL
Group:          Productivity/Databases/Tools
URL:            http://www.pgadmin.org
Source0:        https://download.postgresql.org/pub/pgadmin/%{name}/v%{version}/source/%{name}-%{version}.tar.gz
Source1:        %{name}.conf
Source2:        %{name}.service.in
Source3:        %{name}.tmpfiles.d
Source4:        %{name}.desktop.in
Source5:        %{name}.config_local.py.in
Source6:        %{name}.qt.conf.in
Source7:        README.SUSE
Patch0:         use-os-makedirs.patch
Patch1:         fix-python3-crypto-call.patch
BuildRequires:  Mesa-libGL-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libQt5Core-devel
BuildRequires:  libQt5Network-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  python3-devel
BuildRequires:  systemd-rpm-macros
Requires:       %{name}-web = %{version}
Requires:       python3 >= 3.3
%{?systemd_requires}

%description
pgAdmin 4 is a rewrite of the pgAdmin3 management tool for the
PostgreSQL database. It is written as a web application in Python,
using jQuery and Bootstrap for the client side processing and UI. On
the server side, Flask is being utilised.

This variant is a Qt-based runtime application intended to allow the
standalone use on a workstation - it is essentially a browser and
Python interpretor in one package which will be capable of hosting
the Python application and presenting it to the user as a desktop
application.

%package web
Summary:        Web package for pgAdmin4
Group:          Productivity/Databases/Tools
Requires:       python3-Babel >= 1.3
Requires:       python3-Flask >= 0.12.4
Requires:       python3-Flask-Babel >= 0.11.1
Requires:       python3-Flask-Gravatar >= 0.5.0
Requires:       python3-Flask-HTMLmin >= 1.3.2
Requires:       python3-Flask-Login >= 0.3.2
Requires:       python3-Flask-Mail >= 0.9.1
Requires:       python3-Flask-Migrate >= 2.1.1
Requires:       python3-Flask-Paranoid >= 0.2.0
Requires:       python3-Flask-Principal >= 0.4.0
Requires:       python3-Flask-SQLAlchemy >= 2.3.2
Requires:       python3-Flask-Security >= 3.0.0
Requires:       python3-Flask-WTF >= 0.14.2
Requires:       python3-Jinja2 >= 2.7.3
Requires:       python3-MarkupSafe >= 0.23
Requires:       python3-SQLAlchemy >= 1.2.5
Requires:       python3-WTForms >= 2.1
Requires:       python3-Werkzeug >= 0.9.6
Requires:       python3-beautifulsoup4 >= 4.4.1
Requires:       python3-blinker >= 1.4
Requires:       python3-click
Requires:       python3-extras >= 1.0.0
Requires:       python3-fixtures >= 3.0.0
Requires:       python3-html5lib >= 1.0.1
Requires:       python3-htmlmin >= 0.1.12
Requires:       python3-itsdangerous >= 0.24
Requires:       python3-linecache2 >= 1.0.0
Requires:       python3-passlib >= 1.7.1
Requires:       python3-pbr >= 3.1.1
Requires:       python3-psutil >= 5.4.7
Requires:       python3-psycopg2 >= 2.7.4
Requires:       python3-pycrypto >= 2.6.1
Requires:       python3-pyrsistent >= 0.14.2
Requires:       python3-python-dateutil >= 2.7.1
Requires:       python3-python-mimeparse >= 1.6.0
Requires:       python3-pytz >= 2018.3
Requires:       python3-simplejson >= 3.13.2
Requires:       python3-six >= 1.11.0
Requires:       python3-speaklater >= 1.3
Requires:       python3-sqlparse >= 0.2.4
Requires:       python3-sshtunnel >= 0.1.3
Recommends:     python3-mod_wsgi
Suggests:       %{name}-doc
BuildArch:      noarch

%description web
pgAdmin 4 is a rewrite of the pgAdmin3 management tool for the
PostgreSQL database.

This package contains the required files to run pgAdmin4 as a web application

%package	doc
Summary:        Documentation for pgAdmin4
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
pgAdmin 4 is a rewrite of the pgAdmin3 management tool for the
PostgreSQL database.

This package contains the documentation for pgadmin4.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
cp %{S:7} .

%build
cd runtime
export PYTHON_CONFIG=%{_bindir}/python3-config
export CFLAGS=%{RPM_OPT_FLAGS}
qmake-qt5 -o Makefile pgAdmin4.pro
make %{?_smp_mflags} VERBOSE=1

%install
cd runtime
install -d -m 755 %{buildroot}%{_docdir}/%{name}-docs/
cp -pr ../docs/* %{buildroot}%{_docdir}/%{name}-docs

install -d -m 755 %{buildroot}%{_bindir}
cp pgAdmin4 %{buildroot}%{_bindir}

install -d -m 755 %{buildroot}%{python3_sitelib}/pgadmin4-web
cp -pR ../web/* %{buildroot}%{python3_sitelib}/pgadmin4-web

install -d %{buildroot}%{_sysconfdir}/apache2/conf.d/
install -m 0644 -p %{SOURCE1} %{buildroot}%{_sysconfdir}/apache2/conf.d/%{name}.conf

# Install desktop file
install -d %{buildroot}%{_datadir}/applications/
sed -e 's@PYTHONDIR@%{_bindir}/python3@g' -e 's@PYTHONSITELIB@%{python3_sitelib}@g' < %{SOURCE4} > %{buildroot}%{_datadir}/applications/%{name}.desktop

# Install config_local
install -m 0644 %{SOURCE5} %{buildroot}%{python3_sitelib}/%{name}-web/config_local.py

# Install QT conf file
# This directory will/may change in future releases.
install -d "%{buildroot}%{_sysconfdir}/xdg/pgadmin/"
sed -e 's@PYTHONSITELIB64@%{python3_sitearch}@g' -e 's@PYTHONSITELIB@%{python3_sitelib}@g'<%{SOURCE6} > "%{buildroot}%{_sysconfdir}/xdg/pgadmin/pgadmin4.conf"

# Install unit file/init script
# This is only for systemd supported distros:
install -d %{buildroot}%{_unitdir}
sed -e 's@PYTHONDIR@%{_bindir}/python3@g' -e 's@PYTHONSITELIB@%{python3_sitelib}@g' < %{SOURCE2} > %{buildroot}%{_unitdir}/%{name}.service

# ... and make a tmpfiles script to recreate it at reboot.
mkdir -p %{buildroot}/%{_tmpfilesdir}
install -m 0644 %{SOURCE3} %{buildroot}/%{_tmpfilesdir}/%{name}.conf

cd %{buildroot}%{python3_sitelib}/%{name}-web
rm -f %{name}.db
echo "SERVER_MODE = False" > config_distro.py
echo "HTML_HELP = '%{_datadir}/doc/%{name}-docs/en_US/html/'" >> config_distro.py
chmod -x %{buildroot}%{_docdir}/%{name}-docs/en_US/images/*
rm %{buildroot}%{python3_sitelib}/%{name}-web/regression/.gitignore
rm %{buildroot}%{_docdir}/%{name}-docs/en_US/.gitignore
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcpgadmin4
%fdupes %{buildroot}/%{_prefix}

%pre web
%service_add_pre %{name}.service

%post web
%service_add_post %{name}.service
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%preun web
%service_del_preun %{name}.service

%postun web
%service_del_postun %{name}.service

%files
%doc README README.SUSE
%license LICENSE
%{_bindir}/pgAdmin4
%{_datadir}/applications/%{name}.desktop
%dir %{_sysconfdir}/xdg/pgadmin
%config %{_sysconfdir}/xdg/pgadmin/pgadmin4.conf

%files web
%dir %{python3_sitelib}/%{name}-web/
%{python3_sitelib}/%{name}-web/*
%dir %{_sysconfdir}/apache2
%dir %{_sysconfdir}/apache2/conf.d
%config(noreplace) %{_sysconfdir}/apache2/conf.d/%{name}.conf
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%{_sbindir}/rcpgadmin4
%ghost %dir %{_rundir}/%{name}

%files doc
%dir %{_docdir}/%{name}-docs
%doc %{_docdir}/%{name}-docs/*

%changelog
* Tue Jan 15 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to pgadmin4 4.1
  - Bug fixes
  * Fix SQL generated for tables with inherited columns.
  * Ensure the context menu works after a server is renamed.
  * Fix ordering of VACUUM options which changed in PG11.
  * Don’t show system catalogs in the schemas property list unless
    show system objects is enabled.
  * Fix help for the backup/restore dialogues.
  * Ensure that last row of table data should be visible and user
    will be able to add new row.
  * Make the browser more robust in the face of multibyte characters
    in SQL_ASCII databases.
- Update to pgadmin4 4.0
  - Features
  * Allow query plans to be downloaded as an SVG file.
  * New UI design.
  * Allow servers to be pre-loaded into container deployments.
  - Bug fixes
  * Increase the size of the resize handle of the edit grid text
    pop-out.
  * Fix handling of array types as inputs to the debugger.
  * Fix an issue that could cause the Query Tool to fail to render.
  * Display event trigger functions correctly on EPAS.
  * Further improvements to treeview restoration.
  * Run Postfix in the container build so passwords can be reset etc.
  * Add titles to the code areas of the Query Tool and Debugger to
    ensure that panels can be re-docked within them.
  * Fix a webpack issue that could cause the Query Tool to fail to
    render.
  * Ensure we display the relation name (and not the OID) in the
    locks table wherever possible.
  * Fix an encoding issue in the query tool.
  * Include the WHERE clause on EXCLUDE constraints in RE-SQL.
  * Fix an issue when user define Cast from smallint->text is created.
  * Hide Radio buttons that should not be shown on the maintenance
    dialogue.
  * Ensure that null values handled properly in CSV download.
  * Tweak the wording on the Grant Wizard.
  * Prevent attempts to bulk-drop schema objects.
  * Ensure the browser toolbar buttons work in languages other than
    English.
  * Allow horizontal sizing of the edit grid text pop-out.
  * Ensure auto complete should works when first identifier in the
    FROM clause needs quoting.
  * Ensure auto complete should works for columns from a
    schema-qualified table.
  * Ensure identifiers are properly displayed in the plan viewer.
  * Make the setup process more robust against aborted executions.
  * Fixed an issue while creating export job.
- Make pgadmin4-web suggest the pgadmin4-doc package instead of
  requiring it.
* Fri Nov 30 2018 Antonio Larrosa <alarrosa@suse.com>
- Update to pgadmin4 3.6
  - Features
  * Add support for dropping multiple objects at once from the
    collection Properties panel.
  * Add the ability to import and export server definitions from
    a config database
  - Bug fixes
  * Ensure previous notices are not removed from the Messages tab in
    the Query Tool if an error occurs during query execution.
  * Allow the selection order to be preserved in the Select2 control
    to fix column ordering in data Import/Export.
  * Allow use of 0 (integer) and empty strings as parameters in the debugger.
  * Properly report errors when debugging cannot be started.
  * Prevent the debugger controls being pressed again before previous
    processing is complete.
  * Fix toggle breakpoints buttons in the debugger.
  * Fix changes to the NOT NULL and default value options in the
    Table Dialogue.
  * Fix dropping of multiple functions/procedures at once.
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Compact description and trim first-person grammar.
- Rename pgadmin4-docs to pgadmin4-doc to be in line with
  the naming of other packages in openSUSE.
- Safeguard fdupes to not run over partition boundaries.
* Wed Nov  7 2018 Antonio Larrosa <alarrosa@suse.com>
- Update to pgadmin4 3.5
  - Features
  * Save the treeview state periodically, and restore it automatically when
    reconnecting.
  * Migrate from Bootstrap 3 to Bootstrap 4.
  - Bug fixes
  * Ensure that Utilities(Backup/Restore/Maintenence/Import-Export) should
    not be started if binary path is wrong and also added ‘Stop Process’ button
    to cancel the process.
  * Fix syntax error when creating new pgAgent schedules with a start date/time
    and exception.
  * Cleanup session files periodically.
  * Rename the ‘SQL Editor’ section of the Preferences to ‘Query Tool’ as it
    applies to the whole tool, not just the editor.
  * Fix CREATE Script functionality for EDB-Wrapped functions.
  * Fix connection garbage collector.
  * Purge connections from the cache on logout.
  * Ensure that utility existence check should work for schema and other child
    objects while taking Backup/Restore.
  * Fixed fatal error while launching the pgAdmin4 3.5. Update the version of
    the Flask to 0.12.4 for release.
* Mon Oct  8 2018 Antonio Larrosa <alarrosa@suse.com> - 3.4
- Update to pgadmin4 3.4
  - Features
  * Move all CSS into SCSS files for consistency and ease of colour maintenance etc.
  * Add optional data point markers and mouse-over tooltips to display values on graphs.
  * Add shortcuts for View Data and the Query tool to the Browser header bar.
  - Bug fixes
  * Ensure the runtime can startup properly if there are wide characters in the logfile path on Windows.
  * Fix handling of backslashes in the edit grid.
  * Ensure queries are no longer executed when dashboards are closed.
  * Fix support for the CLOB datatype in EPAS.
  * Fix logic around validation and highlighting of Sort/Filter in the Query Tool.
  * Ensure auto-complete works for objects in schemas other than public and pg_catalog.
  * Ensure changes to Query Tool settings from the Preferences dialogue are applied before executing queries.
  * Swap the Schema and Schemas icons and Catalog and Catalogs icons that had been used the wrong way around.
* Wed Oct  3 2018 Antonio Larrosa <alarrosa@suse.com> - 3.3
- Update to pgadmin4 3.3
  - Features
  * Add a geometry viewer that can render PostGIS data on a blank canvas or various map sources.
  * Added new backup/restore options for PostgreSQL 11. Added dump options for 'pg_dumpall'.
  * Add a Spanish translation.
  - Bug fixes
  * Stabilise feature tests for continuous running on CI systems.
  * Fixed debugger execution issues.
  * Ensure 'select all' and 'unselect all' working properly for pgAgent schedule.
  * Fix sort/filter dialog issue where it incorrectly requires ASC/DESC.
  * Ensure backup should work with '--data-only' and '--schema-only' for any format.
  * Fix keyboard shortcuts layout in the preferences panel.
  * Merge pgcli code with version 1.10.3, which is used for auto complete feature.
  * Ensure that refreshing a node also updates the Property list.
  * Ensure that refresh button on dashboard should refresh the table.
  * Handle connection errors properly in the query tool.
  * Make session implementation thread safe
  * Ensure external table node should be visible only for GPDB.
  * Fix auto scrolling issue in debugger on step in and step out.
  * Fix sort/filter dialog editing issue.
  * Ensure sort/filter dialog should display proper message after losing database connection.
  * Ensure sql for Role should be visible in SQL panel for GPDB.
  * When building the Windows installer, copy system Python packages before installing dependencies to ensure we don't end up with older versions than intended.
  * Correct the documentation of View/Edit data.
* Tue Aug 21 2018 Antonio Larrosa <alarrosa@suse.com> - 3.2
- Initial release of pgadmin4 3.2
